**Example 1: 删除防篡改url**



Input: 

```
tccli waf DeleteAntiFakeUrl --cli-unfold-argument  \
    --Domain www.test.com \
    --Id 123
```

Output: 
```
{
    "Response": {
        "RequestId": "8c20d0a3-9539-4ef8-aea1-06b5ce29e0c9"
    }
}
```

